Index: chrome/browser/instant/instant_model_observer.h |
diff --git a/chrome/browser/instant/instant_model_observer.h b/chrome/browser/instant/instant_model_observer.h |
index 1985fcc177eab45dfd4adb69cd8dc472f8a8434b..2a208f305991dead7d38d76d9c350eeae8b47b69 100644 |
--- a/chrome/browser/instant/instant_model_observer.h |
+++ b/chrome/browser/instant/instant_model_observer.h |
@@ -7,12 +7,12 @@ |
class InstantModel; |
-// This class defines the observer interface for the |InstantModel|. |
+// This class defines the observer interface for the InstantModel. |
class InstantModelObserver { |
public: |
- // Informs the observer that the preview state has changed. This can mean |
- // either the model state changed or the contents of the preview changed. |
- virtual void PreviewStateChanged(const InstantModel& model) = 0; |
+ // Informs the observer that the overlay state has changed. This can mean |
+ // either the model state changed or the contents of the overlay changed. |
+ virtual void OverlayStateChanged(const InstantModel& model) = 0; |
protected: |
~InstantModelObserver() {} |